==> webmin_0.94.orig.tar.gz: webmin-0.94/cron/acl_security.pl <==

require './cron-lib.pl';

# acl_security_form(&options)
# Output HTML for editing security options for the cron module
sub acl_security_form
{
print "<tr> <td valign=top><b>$text{'acl_users'}</b></td> <td colspan=3>\n";
printf "<input type=radio name=mode value=0 %s> $text{'acl_all'}<br>\n",
	$_[0]->{'mode'} == 0 ? "checked" : "";
printf "<input type=radio name=mode value=3 %s> $text{'acl_this'}<br>\n",
	$_[0]->{'mode'} == 3 ? "checked" : "";
printf "<input type=radio name=mode value=1 %s> $text{'acl_only'}\n",
	$_[0]->{'mode'} == 1 ? "checked" : "";
printf "<input name=userscan size=40 value='%s'> %s<br>\n",
	$_[0]->{'mode'} == 1 ? $_[0]->{'users'} : "",
	&user_chooser_button("userscan", 1);
printf "<input type=radio name=mode value=2 %s> $text{'acl_except'}\n",
	$_[0]->{'mode'} == 2 ? "checked" : "";
printf "<input name=userscannot size=40 value='%s'> %s</td> </tr>\n",
	$_[0]->{'mode'} == 2 ? $_[0]->{'users'} : "",
	&user_chooser_button("userscannot", 1);

print "<tr> <td><b>$text{'acl_control'}</b></td> <td>\n";
printf "<input type=radio name=allow value=1 %s> $text{'yes'}\n",
	$_[0]->{'allow'} ? "checked" : "";
printf "<input type=radio name=allow value=0 %s> $text{'no'}</td> </tr>\n",
	$_[0]->{'allow'} ? "" : "checked";
}

# acl_security_save(&options)
# Parse the form for security options for the cron module
sub acl_security_save
{
$_[0]->{'mode'} = $in{'mode'};
$_[0]->{'users'} = $in{'mode'} == 0 || $in{'mode'} == 3 ? "" :
		   $in{'mode'} == 1 ? $in{'userscan'}
				    : $in{'userscannot'};
$_[0]->{'allow'} = $in{'allow'};
}

==> webmin_1.180.orig.tar.gz: webmin-1.180.orig/cron/acl_security.pl <==

require 'cron-lib.pl';

# acl_security_form(&options)
# Output HTML for editing security options for the cron module
sub acl_security_form
{
print "<tr> <td valign=top><b>$text{'acl_users'}</b></td> <td colspan=3>\n";
printf "<input type=radio name=mode value=0 %s> $text{'acl_all'}<br>\n",
	$_[0]->{'mode'} == 0 ? "checked" : "";

printf "<input type=radio name=mode value=3 %s> $text{'acl_this'}<br>\n",
	$_[0]->{'mode'} == 3 ? "checked" : "";

printf "<input type=radio name=mode value=1 %s> $text{'acl_only'}\n",
	$_[0]->{'mode'} == 1 ? "checked" : "";
printf "<input name=userscan size=40 value='%s'> %s<br>\n",
	$_[0]->{'mode'} == 1 ? $_[0]->{'users'} : "",
	&user_chooser_button("userscan", 1);

printf "<input type=radio name=mode value=2 %s> $text{'acl_except'}\n",
	$_[0]->{'mode'} == 2 ? "checked" : "";
printf "<input name=userscannot size=40 value='%s'> %s<br>\n",
	$_[0]->{'mode'} == 2 ? $_[0]->{'users'} : "",
	&user_chooser_button("userscannot", 1);

printf "<input type=radio name=mode value=5 %s> $text{'acl_gid'}\n",
	$_[0]->{'mode'} == 5 ? "checked" : "";
printf "<input name=gid size=8 value='%s'> %s<br>\n",
	$_[0]->{'mode'} == 5 ? scalar(getgrgid($_[0]->{'users'})) : "",
	&group_chooser_button("gid", 0);

printf "<input type=radio name=mode value=4 %s> $text{'acl_uid'}\n",
	$_[0]->{'mode'} == 4 ? "checked" : "";
printf "<input name=uidmin size=6 value='%s'> -\n",
	$_[0]->{'mode'} == 4 ? $_[0]->{'uidmin'} : "";
printf "<input name=uidmax size=6 value='%s'></td> </tr>\n",
	$_[0]->{'mode'} == 4 ? $_[0]->{'uidmax'} : "";

print "<tr> <td><b>$text{'acl_control'}</b></td> <td>\n";
printf "<input type=radio name=allow value=1 %s> $text{'yes'}\n",
	$_[0]->{'allow'} ? "checked" : "";
printf "<input type=radio name=allow value=0 %s> $text{'no'}</td> </tr>\n",
	$_[0]->{'allow'} ? "" : "checked";
}

# acl_security_save(&options)
# Parse the form for security options for the cron module
sub acl_security_save
{
$_[0]->{'mode'} = $in{'mode'};
$_[0]->{'users'} = $in{'mode'} == 0 || $in{'mode'} == 3 ||
		   $in{'mode'} == 4 ? "" :
		   $in{'mode'} == 5 ? scalar(getgrnam($in{'gid'})) :
		   $in{'mode'} == 1 ? $in{'userscan'}
				    : $in{'userscannot'};
$_[0]->{'uidmin'} = $in{'mode'} == 4 ? $in{'uidmin'} : "";
$_[0]->{'uidmax'} = $in{'mode'} == 4 ? $in{'uidmax'} : "";
$_[0]->{'allow'} = $in{'allow'};
}
